@@ -3,48 +3,50 @@ CREATE TABLE presentity (
     username VARCHAR(64) NOT NULL,
     domain VARCHAR(64) NOT NULL,
     event VARCHAR(64) NOT NULL,
-    etag VARCHAR(64) NOT NULL,
+    etag VARCHAR(128) NOT NULL,
     expires INTEGER NOT NULL,
     received_time INTEGER NOT NULL,
     body BYTEA NOT NULL,
-    sender VARCHAR(128) NOT NULL,
+    sender VARCHAR(255) NOT NULL,
     priority INTEGER DEFAULT 0 NOT NULL,
-    CONSTRAINT presentity_presentity_idx UNIQUE (username, domain, event, etag)
+    ruid VARCHAR(64),
+    CONSTRAINT presentity_presentity_idx UNIQUE (username, domain, event, etag),
+    CONSTRAINT presentity_ruid_idx UNIQUE (ruid)
 );
 
 CREATE INDEX presentity_presentity_expires ON presentity (expires);
 CREATE INDEX presentity_account_idx ON presentity (username, domain, event);
 
-INSERT INTO version (table_name, table_version) values ('presentity','4');
+INSERT INTO version (table_name, table_version) values ('presentity','5');
 
 CREATE TABLE active_watchers (
     id SERIAL PRIMARY KEY NOT NULL,
-    presentity_uri VARCHAR(128) NOT NULL,
+    presentity_uri VARCHAR(255) NOT NULL,
     watcher_username VARCHAR(64) NOT NULL,
     watcher_domain VARCHAR(64) NOT NULL,
     to_user VARCHAR(64) NOT NULL,
     to_domain VARCHAR(64) NOT NULL,
     event VARCHAR(64) DEFAULT 'presence' NOT NULL,
     event_id VARCHAR(64),
-    to_tag VARCHAR(64) NOT NULL,
-    from_tag VARCHAR(64) NOT NULL,
+    to_tag VARCHAR(128) NOT NULL,
+    from_tag VARCHAR(128) NOT NULL,
     callid VARCHAR(255) NOT NULL,
     local_cseq INTEGER NOT NULL,
     remote_cseq INTEGER NOT NULL,
-    contact VARCHAR(128) NOT NULL,
+    contact VARCHAR(255) NOT NULL,
     record_route TEXT,
     expires INTEGER NOT NULL,
     status INTEGER DEFAULT 2 NOT NULL,
-    reason VARCHAR(64) NOT NULL,
+    reason VARCHAR(64),
     version INTEGER DEFAULT 0 NOT NULL,
     socket_info VARCHAR(64) NOT NULL,
-    local_contact VARCHAR(128) NOT NULL,
+    local_contact VARCHAR(255) NOT NULL,
     from_user VARCHAR(64) NOT NULL,
     from_domain VARCHAR(64) NOT NULL,
     updated INTEGER NOT NULL,
     updated_winfo INTEGER NOT NULL,
     flags INTEGER DEFAULT 0 NOT NULL,
-    user_agent VARCHAR(255) DEFAULT '' NOT NULL,
+    user_agent VARCHAR(255) DEFAULT '',
     CONSTRAINT active_watchers_active_watchers_idx UNIQUE (callid, to_tag, from_tag)
 );
 
@@ -57,7 +59,7 @@ INSERT INTO version (table_name, table_version) values ('active_watchers','12');
 
 CREATE TABLE watchers (
     id SERIAL PRIMARY KEY NOT NULL,
-    presentity_uri VARCHAR(128) NOT NULL,
+    presentity_uri VARCHAR(255) NOT NULL,
     watcher_username VARCHAR(64) NOT NULL,
     watcher_domain VARCHAR(64) NOT NULL,
     event VARCHAR(64) DEFAULT 'presence' NOT NULL,
@@ -75,7 +77,7 @@ CREATE TABLE xcap (
     domain VARCHAR(64) NOT NULL,
     doc BYTEA NOT NULL,
     doc_type INTEGER NOT NULL,
-    etag VARCHAR(64) NOT NULL,
+    etag VARCHAR(128) NOT NULL,
     source INTEGER NOT NULL,
     doc_uri VARCHAR(255) NOT NULL,
     port INTEGER NOT NULL,
@@ -90,22 +92,22 @@ INSERT INTO version (table_name, table_version) values ('xcap','4');
 
 CREATE TABLE pua (
     id SERIAL PRIMARY KEY NOT NULL,
-    pres_uri VARCHAR(128) NOT NULL,
+    pres_uri VARCHAR(255) NOT NULL,
     pres_id VARCHAR(255) NOT NULL,
     event INTEGER NOT NULL,
     expires INTEGER NOT NULL,
     desired_expires INTEGER NOT NULL,
     flag INTEGER NOT NULL,
-    etag VARCHAR(64) NOT NULL,
+    etag VARCHAR(128) NOT NULL,
     tuple_id VARCHAR(64),
-    watcher_uri VARCHAR(128) NOT NULL,
+    watcher_uri VARCHAR(255) NOT NULL,
     call_id VARCHAR(255) NOT NULL,
-    to_tag VARCHAR(64) NOT NULL,
-    from_tag VARCHAR(64) NOT NULL,
+    to_tag VARCHAR(128) NOT NULL,
+    from_tag VARCHAR(128) NOT NULL,
     cseq INTEGER NOT NULL,
     record_route TEXT,
-    contact VARCHAR(128) NOT NULL,
-    remote_contact VARCHAR(128) NOT NULL,
+    contact VARCHAR(255) NOT NULL,
+    remote_contact VARCHAR(255) NOT NULL,
     version INTEGER NOT NULL,
     extra_headers TEXT NOT NULL,
     CONSTRAINT pua_pua_idx UNIQUE (etag, tuple_id, call_id, from_tag)
