@@ -9,12 +9,14 @@ CREATE TABLE uacreg (
     auth_username VARCHAR(64) DEFAULT '' NOT NULL,
     auth_password VARCHAR(64) DEFAULT '' NOT NULL,
     auth_ha1 VARCHAR(128) DEFAULT '' NOT NULL,
-    auth_proxy VARCHAR(128) DEFAULT '' NOT NULL,
+    auth_proxy VARCHAR(255) DEFAULT '' NOT NULL,
     expires INTEGER DEFAULT 0 NOT NULL,
     flags INTEGER DEFAULT 0 NOT NULL,
     reg_delay INTEGER DEFAULT 0 NOT NULL,
+    contact_addr VARCHAR(255) DEFAULT '' NOT NULL,
+    socket VARCHAR(128) DEFAULT '' NOT NULL,
     CONSTRAINT uacreg_l_uuid_idx UNIQUE (l_uuid)
 );
 
-INSERT INTO version (table_name, table_version) values ('uacreg','3');
+INSERT INTO version (table_name, table_version) values ('uacreg','5');
 
